/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.guest.impl.comparators;

import java.util.Arrays;
import javax.mail.Message.RecipientType;
import com.openexchange.guard.guest.GuardGuestEmail;

/**
 * {@link RecipientComparator}
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v7.10.0
 */
public class RecipientComparator extends GuardGuestEmailComparator {

    private final RecipientType type;

    /**
     * Initializes a new {@link RecipientComparator}.
     *
     * @param type The {@link RecipientType} to compare
     */
    public RecipientComparator(RecipientType type) {
        this.type = type;
    }

    private String[] getRecipients(GuardGuestEmail email, RecipientType type) {
        if (email.getMetaData() != null) {
            if (type == RecipientType.TO) {
                return email.getMetaData().getTo();
            } else if (type == RecipientType.CC) {
                return email.getMetaData().getCc();
            } else if (type == RecipientType.BCC) {
                return email.getMetaData().getBcc();
            }
        }
        return null;
    }

    /*
     * (non-Javadoc)
     *
     * @see com.openexchange.guard.guest.impl.comparators.GuardGuestEmailComparator#compareInternal(com.openexchange.guard.guest.GuardGuestEmail, com.openexchange.guard.guest.GuardGuestEmail)
     */
    @Override
    public int compareEmails(GuardGuestEmail arg0, GuardGuestEmail arg1) {
        String[] recipients0 = getRecipients(arg0, type);
        String[] recipients1 = getRecipients(arg1, type);

        if (Arrays.equals(recipients0, recipients1)) {
            return 0;
        }

        if (checkForNull(recipients0, recipients1)) {
            return compareNull(recipients0, recipients1);
        }

        StringBuilder stringBuilderRecipients0 = new StringBuilder();
        StringBuilder stringBuilderRecipients1 = new StringBuilder();
        Arrays.stream(recipients0).forEach(a -> stringBuilderRecipients0.append(a));
        Arrays.stream(recipients1).forEach(a -> stringBuilderRecipients1.append(a));

        return stringBuilderRecipients0.toString().compareTo(stringBuilderRecipients1.toString());
    }
}
